@@ -1,5 +1,4 @@
 package Catalyst::Helper::View::Email::Template;
-our $VERSION = '0.21_01';
 
 use strict;
 
@@ -7,13 +6,9 @@ use strict;
 
 Catalyst::Helper::View::Email::Template - Helper for Templated Email Views
 
-=head1 VERSION
-
-version 0.21_01
-
 =head1 SYNOPSIS
 
-    $ script/myapp_create.pl view Email::Template Email::Template
+    script/create.pl view Template::Email Template::Email
 
 =head1 DESCRIPTION
 
@@ -87,4 +82,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
