@@ -1,6 +1,5 @@
 package # Hide from PAUSE
     TestApp::View::Email;
-our $VERSION = '0.21_01';
 
 use Email::Send::Test;
 
@@ -8,7 +7,7 @@ use base 'Catalyst::View::Email';
 
 __PACKAGE__->config(
     sender => {
-        mailer => 'Test'
+        method => 'Test'
     },
 );
 
